@@ -1,3 +1,7 @@
+'''The Uplogic Animation Module provides easy to use API for playing and
+controlling animations.
+'''
+
 from .actionsystem import ULActionSystem  # noqa
 from .action import ACTION_FINISHED  # noqa
 from .action import ACTION_STARTED  # noqa
